@@ -11,11 +11,12 @@ class TaskArguments:
     training_args: TrainingArguments = TrainingArguments()
 
 
-def parse_tasks_args(extensionArgs=None) -> (TaskArguments,):
-    task_args = TaskArguments()
-    if extensionArgs is not None:
-        if type(extensionArgs) == type:
-            task_args.extension = extensionArgs()
-        else:
-            task_args.extension = extensionArgs
-    return Arguments(TaskArguments()).parse(), task_args.extension
+def parse_tasks_args(argsObjOrClass=None):
+    if argsObjOrClass is None:
+        task_args = TaskArguments()
+    elif argsObjOrClass is not None and type(argsObjOrClass) != type:
+        task_args = argsObjOrClass
+    else:
+        task_args = argsObjOrClass()
+
+    return Arguments(task_args).parse()
